import sys
if(sys.platform == "win32"):
    import msvcrt
else:
    import select
    import tty
    import termios
import time


# '\x1b' == ESC
def timedInput(prompt: str = "", timeOut: int = 5, forcedTimeout: bool = False, endCharacters: list = ['\x1b', '\n', '\r']):
    if(not sys.__stdin__.isatty()):
        raise RuntimeError(
            "timedInput() requires an interactive shell, cannot continue.")
    userInput = ""
    timeStart = time.time()
    timedOut = False
    if(len(prompt) > 0):
        print(prompt, end='', flush=True)

    if(sys.platform == "win32"):
        while(True):
            if((time.time() - timeStart) >= timeOut):
                timedOut = True
                break
            if(msvcrt.kbhit()):
                inputCharacter = msvcrt.getwche()
                if(inputCharacter in endCharacters):
                    break
                userInput = userInput + inputCharacter
                if(not forcedTimeout):
                    timeStart = time.time()
        print("")
        return userInput, timedOut
    else:
        def checkStdin():
            return select.select([sys.stdin], [], [], 0) == ([sys.stdin], [], [])
        old_settings = termios.tcgetattr(sys.stdin)
        try:
            tty.setcbreak(sys.stdin.fileno())
            while True:
                if((time.time() - timeStart) >= timeOut):
                    timedOut = True
                    break
                if(checkStdin()):
                    inputCharacter = sys.stdin.read(1)
                    if(inputCharacter in endCharacters):
                        break
                    userInput = userInput + inputCharacter
                    print(inputCharacter, end='', flush=True)
                    if(not forcedTimeout):
                        timeStart = time.time()
        finally:
            termios.tcsetattr(sys.stdin, termios.TCSADRAIN, old_settings)
            print("")
            return userInput, timedOut



__title__ = 'pyTimedInput'
__description__ = 'Query user for input with a timeout.'
__url__ = 'https://github.com/werecatf/pytimedinput'
__version__ = '1.0.0'
__author__ = 'WereCatf'
__author_email__ = 'werecatf@runbox.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2020 WereCatf'



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pytimedinput']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pytimedinput',
    'version': '1.0.0',
    'description': 'Query a user for input with a timeout.',
    'long_description': 'pyTimedInput\n============\n\nDescription\n-----------\n\nA tiny, simplistic little alternative to the standard Python input()-function allowing you to specify a timeout for the function.\n\npyTimedInput should work on both Windows and Linux, though no exceedingly extensive testing has been done and there might be bugs.\n\nInstall\n-------\n\n.. code:: bash\n\n    $ pip3 install pyTimedInput\n\nUsage\n-----\n\n.. code:: python\n\n    def timedInput(prompt="", timeOut=5, forcedTimeout=False, endCharacters=[\'\\x1b\', \'\\n\', \'\\r\'])\n\nThe function timedInput() from pyTimedInput accepts the following parameters:\n - prompt, str: a string to show the user as a prompt when waiting for input.\n     *Defaults to an empty string.*\n - timeout: how many seconds to wait before timing out.\n     *Defaults to 5 seconds.*\n - forcedTimeout: whether to wait for \'timeout\' many seconds consecutively or simply time out regardless of user-input.\n     *Defaults to False, ie. consecutive.*\n - endCharacters[]: what characters to consider as end-of-input.\n     *Defaults to new-line, carrier-feed and ESC-key.*\n\nThe function returns a string containing whatever user entered and a boolean whether the input timed out or not.\n\n.. code:: python\n\n    from pyTimedInput import timedInput\n    userText, timedOut = timedInput("Please, do enter something: ")\n    if(timedOut):\n        print("Timed out when waiting for input.")\n        print(f"User-input so far: \'{userText}\'")\n    else:\n        print(f"User-input: \'{userText}\'")\n\nLicense\n-------\n\nMIT',
    'author': 'WereCatf',
    'author_email': 'werecatf@runbox.com',
    'maintainer': 'WereCatf',
    'maintainer_email': 'werecatf@runbox.com',
    'url': 'https://github.com/werecatf/pyTimedInput/',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
